# quasar 🌌
### The build tool for the [qb](https://pypi.org/project/qb/) programming language.

Install using pipx:
```bash
pipx install qb-quasar
```

Then run
```bash 
quasar help
```

and run

```bash
quasar init <name>
```

to create a new project.

After running
```bash
quasar build
```

use 
```bash
quasar run python src/<name>/<file>.py
```

to run your project.